==> feii-0.4.0-py3-none-any.whl: feii/commands/update/cmd_timeout.py <==
#!/usr/bin/python3

import click
from feii.main import class_structure, class_log, logging_level, updating_variables, generating_variables, generating_variables_for_update, deleting_unnecessary_variables
from feii.update import Update

class_update = Update()
class_update.logger = class_log.logger

def start_update_timeout_all(check_mode):
  if not check_mode:
    class_update.update_timeout_for_last_indexes()
    class_update.update_timeout_for_not_last_indexes()

def start_check_update_timeout_all(check_mode):
  if check_mode:
    class_update.update_timeout_for_hot_box_indexes_in_check_mode()

@click.command(short_help='Update setting index.unassigned.node_left.delayed_timeout.')
@click.option(
  '-c', '--check-mode',
  is_flag=True,
  expose_value=True,
  help='Only displaying actions, without performing them.'
)
@click.option(
  '-l', '--log-level',
  default='info',
  show_default=True,
  expose_value=True,
  help='Set the logging level ("debug"|"info"|"warning"|"error"|"critical")'
)
@click.option(
  '-p', '--path_to_file',
  default='',
  expose_value=True,
  help='path'
)
def cli(check_mode, log_level, path_to_file):
  """Update setting index.unassigned.node_left.delayed_timeout"""

  logging_level(log_level)
  class_log.logger.info("Started update index settings")

  updating_variables(path_to_file)

  generating_variables()
  generating_variables_for_update()
  deleting_unnecessary_variables()

  start_update_timeout_all(check_mode)
  start_check_update_timeout_all(check_mode)

if __name__ == "__main__":
  cli()

==> feii-0.5.1-py3-none-any.whl: feii/commands/update/cmd_timeout.py <==
#!/usr/bin/python3

import click
from feii.main import class_structure, class_log, logging_level, updating_variables, generating_variables, generating_variables_for_update, deleting_unnecessary_variables
from feii.update import Update

class_update = Update()
class_update.logger = class_log.logger

def start_update_timeout_all(check_mode):
  if not check_mode:
    class_update.update_timeout_for_last_indexes()
    class_update.update_timeout_for_not_last_indexes()

def start_check_update_timeout_all(check_mode):
  if check_mode:
    class_update.update_timeout_for_last_indexes_check_mode()
    class_update.update_timeout_for_not_last_indexes_check_mode()

@click.command(short_help='Update setting index.unassigned.node_left.delayed_timeout.')
@click.option(
  '-c', '--check-mode',
  is_flag=True,
  expose_value=True,
  help='Only displaying actions, without performing them.'
)
@click.option(
  '-l', '--log-level',
  default='info',
  show_default=True,
  expose_value=True,
  help='Set the logging level ("debug"|"info"|"warning"|"error"|"critical")'
)
@click.option(
  '-p', '--path_to_file',
  default='',
  expose_value=True,
  help='path'
)
def cli(check_mode, log_level, path_to_file):
  """Update setting index.unassigned.node_left.delayed_timeout"""

  logging_level(log_level)
  class_log.logger.info("Started update index settings")

  updating_variables(path_to_file)

  generating_variables()
  generating_variables_for_update()
  deleting_unnecessary_variables()

  start_update_timeout_all(check_mode)
  start_check_update_timeout_all(check_mode)

if __name__ == "__main__":
  cli()
